@@ -23,10 +23,9 @@
 
 #include <config.h>
 #include <glib/gi18n.h>
-#include <libgnome/gnome-util.h>
-#include <libgnomeui/gnome-about.h>
 #include <libanjuta/anjuta-shell.h>
 #include <libanjuta/anjuta-debug.h>
+#include <libanjuta/anjuta-project.h>
 #include <libanjuta/interfaces/ianjuta-document-manager.h>
 #include <libanjuta/interfaces/ianjuta-project-manager.h>
 #include <libanjuta/interfaces/ianjuta-preferences.h>
@@ -184,7 +183,7 @@ on_menu_run_activate (GtkAction *action, AnjutaValgrindPlugin *plugin)
 			
 	exec_targets =
 		ianjuta_project_manager_get_targets (pm,
-						 IANJUTA_PROJECT_MANAGER_TARGET_EXECUTABLE,
+						 ANJUTA_TARGET_EXECUTABLE,
 						 NULL);
 
 	if (exec_targets) {
@@ -207,7 +206,7 @@ on_menu_run_activate (GtkAction *action, AnjutaValgrindPlugin *plugin)
 		bxml = gtk_builder_new ();
 		if (!gtk_builder_add_from_file (bxml, GLADE_FILE, &error))
 		{
-			g_warning ("Couldn't load builder file: s", error->message);
+			g_warning ("Couldn't load builder file: %s", error->message);
 			g_error_free (error);
 		}
 
@@ -229,7 +228,7 @@ on_menu_run_activate (GtkAction *action, AnjutaValgrindPlugin *plugin)
 		node = exec_targets;	
 
 		anjuta_shell_get (ANJUTA_PLUGIN (plugin)->shell,
-			"project_root_uri", G_TYPE_STRING,
+			IANJUTA_PROJECT_MANAGER_PROJECT_ROOT_URI, G_TYPE_STRING,
 			&project_root_uri, NULL);
 		project_root_uri_len = strlen(project_root_uri) + 1;
 	
